A dataset simulated with one exogenous regressor X and one endogenous continuous regressor P, and a dependent variable y. The exogenous regressor X follows a normal distribution with mean 1 and is correlated with P (r = 0.5). The endogenous regressor P follows a bounded continuous distribution (Phi(P*) + 0.5). The endogeneity strength is rho = 0.5. There is no intercept in the data generating process. The true parameter values are given as alpha = 1 for P and beta = 1 for X.

data("dataCopIMAContExo")

Format

A data frame with 1000 observations on 3 variables:

y

a numeric vector representing the dependent variable.

X

a numeric vector, normally distributed with mean 1, exogenous and correlated with P.

P

a numeric vector, continuous and endogenous, following a bounded distribution Phi(P*) + 0.5 with values in (0.5, 1.5).

References

Haschka, R. E. (2025). Robustness of copula-correction models in causal analysis: Exploiting between-regressor correlation. IMA Journal of Management Mathematics, 36, 161-180. doi:10.1093/imaman/dpae018

Author

Kimberly Lew kimberlylew12@gmail.com