A dataset simulated with two endogenous continuous regressors P1 and P2, an intercept, and a dependent variable y. No exgenous regressor. Both endogenous regressors follow a bounded continuous distribution (Phi(P*) + 0.5) and are correlated with each other (r = 0.3), and with the structural error (endogeneity strength rho = 0.5). The true parameter values are alpha1 = 1 for P1, alpha2 = 1 for P2, and mu = 10 for the intercept.This was simulated as an extension to the dataset 'dataCopIMAContExo'. This dataset was created to test how well copulaIMA() works with an intercept and no exogenous regressor.

data("dataCopIMAMultiEndo")

Format

A data frame with 1000 observations on 4 variables:

y

a numeric vector representing the dependent variable.

P1

a numeric vector, continuous and endogenous, following a bounded distribution Phi(P1*) + 0.5 with values in (0.5, 1.5), correlated with P2 (r = 0.3).

P2

a numeric vector, continuous and endogenous, following a bounded distribution Phi(P2*) + 0.5 with values in (0.5, 1.5), correlated with P1 (r = 0.3).

References

Haschka, R. E. (2025). Robustness of copula-correction models in causal analysis: Exploiting between-regressor correlation. IMA Journal of Management Mathematics, 36, 161-180. doi:10.1093/imaman/dpae018

Author

Kimberly Lew kimberlylew12@gmail.com