call- function call.
formula- model formula.
coefficients- estimated coefficients.
seCoefficients- standard error of the estimates.
fitted.values- fitted values.
residuals- estimation residuals.
groupMeans- estimates means of the assumed latent groups.
seMeans- standard errors of the estimates of the groups' means.
sigma- variance -covariance matrix.
probG1- probability of group 1.
seProbG1- standard error of the estimate of the probability of group 1.
initValues- initial values of the parameters.
value- the value of the maximum likelihood function.
AIC- Akaike Information Criterion.
BIC- Bayesian Information Criterion.
convCode- convergence code. If equalt to zero the model has converged.
hessian- the hessian matrix.
dataset- a matrix containing the dependent variable and the endogenous regressor.