Learn R Programming

REndo (version 2.4.3)

vcov.rendo.boots: Calculate Variance-Covariance Matrix for Models Fitted with Bootstrapped Parameters

Description

The variance-covariance matrix is derived from the bootstrapped parameter estimates stored in the object. It is based on Efron (1979) and calculates the result as follows:

where B is the number of bootstraps and is the mean of the bootstrapped coefficients.

Usage

# S3 method for rendo.boots
vcov(object, ...)

Arguments

object

a fitted model object with bootstrapped parameters. Typically from copulaCorrection

...

ignored, for consistency with the generic function.

Value

A matrix of the estimated covariances between the parameter estimates of the model. The row and column names correspond to the parameter names given by the coef method.

References

Effron, B.(1979). "Bootstrap Methods: Another Look at the Jackknife", The Annals of Statistics, 7(1), 1-26.